Tron - Batch Scheduling System
==============================

Tron is a centralized system for managing periodic batch processes and services
across a cluster. If you find [cron](http://en.wikipedia.org/wiki/Cron) or
[fcron](http://fcron.free.fr/) to be insufficient for managing complex work
flows across multiple computers, Tron might be for you.

Install with:

    > sudo pip install tron

Or look at the [tutorial](http://packages.python.org/tron/tutorial.html).

The full documentation is available [on PyPI](http://packages.python.org/tron).

Contributing
------------

Read [Working on Tron](http://packages.python.org/tron/developing.html) and
start sending pull requests!

Any issues should be either posted and discussed [on
Github](http://github.com/Yelp/Tron/issues) or emailed to yelplabs@yelp.com.
